# AL360° Trustworthy AI Utilities for Python

### This package has been tested with Python 3.7, 3.8, 3.9, 3.10 and 3.11

The AL360° Trustworthy AI Utilities package contains common functions shared across various RAI tools, including fairlearn, interpret-community, al360_trustworthyai, al360_taiwidgets and other packages, as well as notebook examples.

Please see the main documentation website:
https://responsibleaitoolbox.ai/

The open source code can be found here:
https://github.com/affectlog360/al360-trustworthy-ai-widgets
